@@ -1,5 +1,5 @@
 /*
-  $Id: MbtServerBase.cxx 13845 2012-01-02 16:36:23Z sloot $
+  $Id: MbtServerBase.cxx 15155 2012-09-04 10:35:45Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/MbtServer/src/MbtServerBase.cxx $
   Copyright (c) 1998 - 2012
   ILK   - Tilburg University
@@ -83,11 +83,10 @@ namespace MbtServer {
 	else {
 	  string base = line.substr(0,ispos);
 	  string rest = line.substr( ispos+1 );
-	  base = compress(base);
-	  rest = compress(rest);
+	  base = trim(base);
+	  rest = trim(rest);
 	  if ( !rest.empty() ){
-	    string tmp = base;
-	    lowercase(tmp);
+	    string tmp = lowercase(base);
 	    if ( tmp == "maxconn" ){
 	      if ( !stringTo( rest, maxConn ) ){
 		cerr << "invalid value for maxconn" << endl;
@@ -262,8 +261,8 @@ namespace MbtServer {
   inline void Split( const string& line, string& com, string& rest ){
     string::size_type b_it = line.find( '=' );
     if ( b_it != string::npos ){
-      com = compress( line.substr( 0, b_it ) );
-      rest = compress( line.substr( b_it+1 ) );
+      com = trim( line.substr( 0, b_it ) );
+      rest = trim( line.substr( b_it+1 ) );
     }
     else {
       rest.clear();
